@@ -27,10 +27,13 @@
 // PKG_ADD: autoload ("zmq_curve_keypair", "zeromq.oct");
 DEFUN_DLD (zmq_curve_keypair, args, nargout,
         "-*- texinfo -*-\n \
-@deftypefn {Loadable Function} [ @var{publickey}, @var{privatekey} ]  =  zmq_curve_keypair ()\n \
+@deftypefn {} {[ @var{publickey}, @var{privatekey} ] =} zmq_curve_keypair ()\n \
 \n\
 Generate a random private/public keypair\n \
 \n \
+@subsubheading Inputs\n \
+None\n \
+@subsubheading Outputs\n \
 @var{publickey} is a string that is the encoded public key\n \
 \n \
 @var{privatekey} is a string that is the encoded private key\n \
